@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     CustomStepStatusType,
@@ -157,7 +157,7 @@ _OptionalCreateAccessRequestRequestTypeDef = TypedDict(
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
+        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
         "Policy": str,
         "PosixProfile": "PosixProfileTypeDef",
     },
@@ -191,9 +191,9 @@ CreateServerRequestRequestTypeDef = TypedDict(
         "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "IdentityProviderType": IdentityProviderTypeType,
         "LoggingRole": str,
-        "Protocols": List[ProtocolType],
+        "Protocols": Sequence[ProtocolType],
         "SecurityPolicyName": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "WorkflowDetails": "WorkflowDetailsTypeDef",
     },
     total=False,
@@ -220,11 +220,11 @@ _OptionalCreateUserRequestRequestTypeDef = TypedDict(
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
+        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
         "Policy": str,
         "PosixProfile": "PosixProfileTypeDef",
         "SshPublicKeyBody": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -248,15 +248,15 @@ CreateUserResponseTypeDef = TypedDict(
 _RequiredCreateWorkflowRequestRequestTypeDef = TypedDict(
     "_RequiredCreateWorkflowRequestRequestTypeDef",
     {
-        "Steps": List["WorkflowStepTypeDef"],
+        "Steps": Sequence["WorkflowStepTypeDef"],
     },
 )
 _OptionalCreateWorkflowRequestRequestTypeDef = TypedDict(
     "_OptionalCreateWorkflowRequestRequestTypeDef",
     {
         "Description": str,
-        "OnExceptionSteps": List["WorkflowStepTypeDef"],
-        "Tags": List["TagTypeDef"],
+        "OnExceptionSteps": Sequence["WorkflowStepTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -581,11 +581,11 @@ EfsFileLocationTypeDef = TypedDict(
 EndpointDetailsTypeDef = TypedDict(
     "EndpointDetailsTypeDef",
     {
-        "AddressAllocationIds": List[str],
-        "SubnetIds": List[str],
+        "AddressAllocationIds": Sequence[str],
+        "SubnetIds": Sequence[str],
         "VpcEndpointId": str,
         "VpcId": str,
-        "SecurityGroupIds": List[str],
+        "SecurityGroupIds": Sequence[str],
     },
     total=False,
 )
@@ -964,7 +964,7 @@ _RequiredPosixProfileTypeDef = TypedDict(
 _OptionalPosixProfileTypeDef = TypedDict(
     "_OptionalPosixProfileTypeDef",
     {
-        "SecondaryGids": List[int],
+        "SecondaryGids": Sequence[int],
     },
     total=False,
 )
@@ -1065,7 +1065,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "Arn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1073,7 +1073,7 @@ TagStepDetailsTypeDef = TypedDict(
     "TagStepDetailsTypeDef",
     {
         "Name": str,
-        "Tags": List["S3TagTypeDef"],
+        "Tags": Sequence["S3TagTypeDef"],
     },
     total=False,
 )
@@ -1126,7 +1126,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "Arn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1142,7 +1142,7 @@ _OptionalUpdateAccessRequestRequestTypeDef = TypedDict(
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
+        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
         "Policy": str,
         "PosixProfile": "PosixProfileTypeDef",
         "Role": str,
@@ -1182,7 +1182,7 @@ _OptionalUpdateServerRequestRequestTypeDef = TypedDict(
         "HostKey": str,
         "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "LoggingRole": str,
-        "Protocols": List[ProtocolType],
+        "Protocols": Sequence[ProtocolType],
         "SecurityPolicyName": str,
         "WorkflowDetails": "WorkflowDetailsTypeDef",
     },
@@ -1216,7 +1216,7 @@ _OptionalUpdateUserRequestRequestTypeDef = TypedDict(
     {
         "HomeDirectory": str,
         "HomeDirectoryType": HomeDirectoryTypeType,
-        "HomeDirectoryMappings": List["HomeDirectoryMapEntryTypeDef"],
+        "HomeDirectoryMappings": Sequence["HomeDirectoryMapEntryTypeDef"],
         "Policy": str,
         "PosixProfile": "PosixProfileTypeDef",
         "Role": str,
@@ -1271,7 +1271,7 @@ WorkflowDetailTypeDef = TypedDict(
 WorkflowDetailsTypeDef = TypedDict(
     "WorkflowDetailsTypeDef",
     {
-        "OnUpload": List["WorkflowDetailTypeDef"],
+        "OnUpload": Sequence["WorkflowDetailTypeDef"],
     },
 )
 
